@@ -53,14 +53,14 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "Inulin", "Laminarin", "Mannan", "Pectin", "N-Acetyl-D-Galactosamine", 
 "N-Acetyl-Neuraminic Acid", "b-D-Allose", "Amygdalin", "D-Arabinose", 
 "D-Arabitol", "L-Arabitol", "Arbutin", "2-Deoxy-D-Ribose", "i-Erythritol", 
-"D-Fucose", "3-0-b-D-Galactopyranosyl-D-Arabinose", "Gentiobiose", 
+"D-Fucose", "3-O-b-D-Galactopyranosyl-D-Arabinose", "Gentiobiose", 
 "L-Glucose", "D-Lactitol", "D-Melezitose", "Maltitol", "a-Methyl-D-Glucoside", 
 "b-Methyl-D-Galactoside", "3-O-Methyl-Glucose", "b-Methyl-D-Glucuronic Acid", 
 "a-Methyl-D-Mannoside", "b-Methyl-D-Xyloside", "Palatinose", 
 "D-Raffinose", "Salicin", "Sedoheptulosan", "L-Sorbose", "Stachyose", 
 "D-Tagatose", "Turanose", "Xylitol", "N-Acetyl-D-Glucosaminitol", 
 "g-Amino-Butyric Acid", "d-Amino-Valeric Acid", "Butyric Acid", 
-"Capric Acid", "Caproic Acid", "Citraconic Acid", "D,L-Citramalic Acid", 
+"Capric Acid", "Caproic Acid", "Citraconic Acid", "D-Citramalic Acid", 
 "D-Glucosamine", "2-Hydroxy-Benzoic Acid", "4-Hydroxy-Benzoic Acid", 
 "b-Hydroxy-Butyric Acid", "g-Hydroxy-Butyric Acid", "a-Keto-Valeric Acid", 
 "Itaconic Acid", "5-Keto-D-Gluconic Acid", "D-Lactic Acid Methyl Ester", 
@@ -72,15 +72,15 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "L-Isoleucine", "L-Leucine", "L-Lysine", "L-Methionine", "L-Ornithine", 
 "L-Phenylalanine", "L-Pyroglutamic Acid", "L-Valine", "D,L-Carnitine", 
 "Butylamine (sec)", "D,L-Octopamine", "Putrescine", "Dihydroxy-Acetone", 
-"2,3-Butanediol", "2,3-Butanone", "3-Hydroxy-2-Butanone", "Negative Control", 
-"Ammonia", "Nitrite", "Nitrate", "Urea", "Biuret", "L-Alanine", 
-"L-Arginine", "L-Asparagine", "L-Aspartic Acid", "L-Cysteine", 
-"L-Glutamic Acid", "L-Glutamine", "Glycine", "L-Histidine", "L-Isoleucine", 
-"L-Leucine", "L-Lysine", "L-Methionine", "L-Phenylalanine", "L-Proline", 
-"L-Serine", "L-Threonine", "L-Tryptophan", "L-Tyrosine", "L-Valine", 
-"D-Alanine", "D-Asparagine", "D-Aspartic Acid", "D-Glutamic Acid", 
+"2,3-Butanediol", "2,3-Butanedione", "3-Hydroxy-2-Butanone", 
+"Negative Control", "Ammonia", "Nitrite", "Nitrate", "Urea", 
+"Biuret", "L-Alanine", "L-Arginine", "L-Asparagine", "L-Aspartic Acid", 
+"L-Cysteine", "L-Glutamic Acid", "L-Glutamine", "Glycine", "L-Histidine", 
+"L-Isoleucine", "L-Leucine", "L-Lysine", "L-Methionine", "L-Phenylalanine", 
+"L-Proline", "L-Serine", "L-Threonine", "L-Tryptophan", "L-Tyrosine", 
+"L-Valine", "D-Alanine", "D-Asparagine", "D-Aspartic Acid", "D-Glutamic Acid", 
 "D-Lysine", "D-Serine", "D-Valine", "L-Citrulline", "L-Homoserine", 
-"L-Ornithine", "N-Acetyl-D,L-Glutamic Acid", "N-Phthaloyl-L-Glutamic Acid", 
+"L-Ornithine", "N-Acetyl-L-Glutamic Acid", "N-Phthaloyl-L-Glutamic Acid", 
 "L-Pyroglutamic Acid", "Hydroxylamine", "Methylamine", "N-Amylamine", 
 "N-Butylamine", "Ethylamine", "Ethanolamine", "Ethylenediamine", 
 "Putrescine", "Agmatine", "Histamine", "b-Phenylethylamine", 
@@ -143,12 +143,12 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "Quinolinic Acid", "Nicotinic Acid", "Nicotinamide", "b-Nicotinamide Adenine Dinucleotide", 
 "d-Amino-Levulinic Acid", "Hematin", "Deferoxamine Mesylate", 
 "D-(+)-Glucose", "N-Acetyl-D-Glucosamine", "Thymine", "Glutathione (reduced form)", 
-"Thymidine", "Oxaloacetic Acid", "D-Biotin", "Cyano-Cobalamine", 
+"Thymidine", "Oxaloacetic Acid", "D-Biotin", "Cyanocobalamin", 
 "p-Amino-Benzoic Acid", "Folic Acid", "Inosine + Thiamine", "Thiamine", 
 "Thiamine Pyrophosphate", "Riboflavin", "Pyrrolo-Quinoline Quinone", 
 "Menadione", "m-Inositol", "Butyric Acid", "D,L-a-Hydroxy-Butyric Acid", 
 "a-Keto-Butyric Acid", "Caprylic Acid", "D,L-a-Lipoic Acid (oxidized form)", 
-"D,L-Mevalonic Acid", "D,L-Carnitine", "Choline", "Tween 20", 
+"D,L-Mevalonic Acid Lactone", "D,L-Carnitine", "Choline", "Tween 20", 
 "Tween 40", "Tween 60", "Tween 80", "Negative Control", "L-Glutamine", 
 "Ala-Ala", "Ala-Arg", "Ala-Asn", "Ala-Glu", "Ala-Gly", "Ala-His", 
 "Ala-Leu", "Ala-Lys", "Ala-Phe", "Ala-Pro", "Ala-Ser", "Ala-Thr", 
@@ -182,27 +182,27 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "Tyr-Gly", "Tyr-His", "Tyr-Leu", "Tyr-Lys", "Tyr-Phe", "Tyr-Trp", 
 "Tyr-Tyr", "Val-Arg", "Val-Asn", "Val-Asp", "Val-Gly", "Val-His", 
 "Val-Ile", "Val-Leu", "Val-Tyr", "Val-Val", "g-Glu-Gly", "Negative Control", 
-"L-Glutamine", "Ala-Asp", "Ala-Gln", "Ala-lle", "Ala-Met", "Ala-Val", 
+"L-Glutamine", "Ala-Asp", "Ala-Gln", "Ala-Ile", "Ala-Met", "Ala-Val", 
 "Asp-Ala", "Asp-Gln", "Asp-Gly", "Glu-Ala", "Gly-Asn", "Gly-Asp", 
-"Gly-lle", "His-Ala", "His-Glu", "His-His", "Ile-Asn", "Ile-Leu", 
+"Gly-Ile", "His-Ala", "His-Glu", "His-His", "Ile-Asn", "Ile-Leu", 
 "Leu-Asn", "Leu-His", "Leu-Pro", "Leu-Tyr", "Lys-Asp", "Lys-Gly", 
 "Lys-Met", "Met-Thr", "Met-Tyr", "Phe-Asp", "Phe-Glu", "Gln-Glu", 
 "Phe-Met", "Phe-Tyr", "Phe-Val", "Pro-Arg", "Pro-Asn", "Pro-Glu", 
-"Pro-lle", "Pro-Lys", "Pro-Ser", "Pro-Trp", "Pro-Val", "Ser-Asn", 
+"Pro-Ile", "Pro-Lys", "Pro-Ser", "Pro-Trp", "Pro-Val", "Ser-Asn", 
 "Ser-Asp", "Ser-Gln", "Ser-Glu", "Thr-Asp", "Thr-Gln", "Thr-Phe", 
-"Thr-Ser", "Trp-Val", "a-Keto-Butyric Acid", "Tyr-Val", "Val-Ala", 
-"Val-Gln", "Val-Glu", "Val-Lys", "Val-Met", "Val-Phe", "Val-Pro", 
-"Val-Ser", "b-Ala-Ala", "b-Ala-Gly", "b-Ala-His", "Met-b-Ala", 
-"b-Ala-Phe", "D-Ala-D-Ala", "D-Ala-Gly", "D-Ala-Leu", "D-Leu-D-Leu", 
-"D-Leu-Gly", "D-Leu-Tyr", "g-Glu-Gly", "g-D-Glu-Gly", "Gly-D-Ala", 
-"Gly-D-Asp", "Gly-D-Ser", "Gly-D-Thr", "Gly-D-Val", "Leu-b-Ala", 
-"Leu-D-Leu", "Phe-b-Ala", "Ala-Ala-Ala", "D-Ala-Gly-Gly", "Gly-Gly-Ala", 
-"Gly-Gly-D-Leu", "Gly-Gly-Gly", "Gly-Gly-lle", "Gly-Gly-Leu", 
-"Gly-Gly-Phe", "Val-Tyr-Val", "Gly-Phe-Phe", "Leu-Gly-Gly", "Leu-Leu-Leu", 
-"Phe-Gly-Gly", "Tyr-Gly-Gly", "1% NaCl", "2% NaCl", "3% NaCl", 
-"4% NaCl", "5% NaCl", "5.5% NaCl", "6% NaCl", "6.5% NaCl", "7% NaCl", 
-"8% NaCl", "9% NaCl", "10% NaCl", "6% NaCl", "6% NaCl + Betaine", 
-"6% NaCl + N-N Dimethyl Glycine", "6% NaCl + Sarcosine", "6% NaCl + Dimethyl Sulphonyl Propionate", 
+"Thr-Ser", "Trp-Val", "Tyr-Ile", "Tyr-Val", "Val-Ala", "Val-Gln", 
+"Val-Glu", "Val-Lys", "Val-Met", "Val-Phe", "Val-Pro", "Val-Ser", 
+"b-Ala-Ala", "b-Ala-Gly", "b-Ala-His", "Met-b-Ala", "b-Ala-Phe", 
+"D-Ala-D-Ala", "D-Ala-Gly", "D-Ala-Leu", "D-Leu-D-Leu", "D-Leu-Gly", 
+"D-Leu-Tyr", "g-Glu-Gly", "g-D-Glu-Gly", "Gly-D-Ala", "Gly-D-Asp", 
+"Gly-D-Ser", "Gly-D-Thr", "Gly-D-Val", "Leu-b-Ala", "Leu-D-Leu", 
+"Phe-b-Ala", "Ala-Ala-Ala", "D-Ala-Gly-Gly", "Gly-Gly-Ala", "Gly-Gly-D-Leu", 
+"Gly-Gly-Gly", "Gly-Gly-Ile", "Gly-Gly-Leu", "Gly-Gly-Phe", "Val-Tyr-Val", 
+"Gly-Phe-Phe", "Leu-Gly-Gly", "Leu-Leu-Leu", "Phe-Gly-Gly", "Tyr-Gly-Gly", 
+"1% NaCl", "2% NaCl", "3% NaCl", "4% NaCl", "5% NaCl", "5.5% NaCl", 
+"6% NaCl", "6.5% NaCl", "7% NaCl", "8% NaCl", "9% NaCl", "10% NaCl", 
+"6% NaCl", "6% NaCl + Betaine", "6% NaCl + N-N Dimethyl Glycine", 
+"6% NaCl + Sarcosine", "6% NaCl + Dimethyl Sulphonyl Propionate", 
 "6% NaCl + MOPS", "6% NaCl + Ectoine", "6% NaCl + Choline", "6% NaCl + Phosphorylcholine", 
 "6% NaCl + Creatine", "6% NaCl + Creatinine", "6% NaCl + L-Carnitine", 
 "6% NaCl + KCl", "6% NaCl + L-Proline", "6% NaCl + N-Acetyl-L-Glutamine", 
@@ -237,41 +237,41 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "pH 4.5 + L-Histidine", "pH 4.5 + L-Isoleucine", "pH 4.5 + L-Leucine", 
 "pH 4.5 + L-Lysine", "pH 4.5 + L-Methionine", "pH 4.5 + L-Phenylalanine", 
 "pH 4.5 + L-Proline", "pH 4.5 + L-Serine", "pH 4.5 + L-Threonine", 
-"pH 4.5 + L-Tryptophan", "pH 4.5 + L-Tyrosine", "pH 4.5 + L-Valine", 
+"pH 4.5 + L-Tryptophan", "pH 4.5 + L-Citrulline", "pH 4.5 + L-Valine", 
 "pH 4.5 + Hydroxy-L-Proline", "pH 4.5 + L-Ornithine", "pH 4.5 + L-Homoarginine", 
 "pH 4.5 + L-Homoserine", "pH 4.5 + Anthranilic Acid", "pH 4.5 + L-Norleucine", 
-"pH 4.5 + L-Norvaline", "pH 4.5 + a-Amino-N-Butyric Acid", "pH 4.5 + a-Amino Malonate", 
-"pH 4.5 + b-Hydroxy-Glutamate", "pH 4.5 + g-Hydroxy-Glutamic Acid", 
-"pH 4.5 + 5-Hydroxy-L-Lysine", "pH 4.5 + 5-Hydroxy-L-Tryptophan", 
-"pH 4.5 + D,L Diamino-Pimelic Acid", "pH 4.5 + Trimethylamine-N-Oxide", 
-"pH 4.5 + Urea", "pH 9.5", "pH 9.5 + L-Alanine", "pH 9.5 + L-Arginine", 
-"pH 9.5 + L-Asparagine", "pH 9.5 + L-Aspartic Acid", "pH 9.5 + L-Glutamic Acid", 
-"pH 9.5 + L-Glutamine", "pH 9.5 + Glycine", "pH 9.5 + L-Histidine", 
-"pH 9.5 + L-Isoleucine", "pH 9.5 + L-Leucine", "pH 9.5 + L-Lysine", 
-"pH 9.5 + L-Methionine", "pH 9.5 + L-Phenylalanine", "pH 9.5 + L-Proline", 
-"pH 9.5 + L-Serine", "pH 9.5 + L-Threonine", "pH 9.5 + L-Tryptophan", 
-"pH 9.5 + L-Tyrosine", "pH 9.5 + L-Valine", "pH 9.5 + Hydroxy-L-Proline", 
-"pH 9.5 + L-Ornithine", "pH 9.5 + L-Homoarginine", "pH 9.5 + L-Homoserine", 
-"pH 9.5 + Anthranilic Acid", "pH 9.5 + L-Norleucine", "pH 9.5 + L-Norvaline", 
-"pH 9.5 + Agmatine", "pH 9.5 + Cadaverine", "pH 9.5 + Putrescine", 
-"pH 9.5 + Histamine", "pH 9.5 + Phenylethylamine", "pH 9.5 + Tyramine", 
-"pH 9.5 + Tryptamine", "pH 9.5 + Trimethylamine-N-Oxide", "pH 9.5 + Urea", 
-"X-Caprylate", "X-a-D-Glucoside", "X-b-D-Glucoside", "X-a-D-Galactoside", 
-"X-b-D-Galactoside", "X-a-D-Glucuronide", "X-b-D-Glucuronide", 
-"X-b-D-Glucosaminide", "X-b-D-Galactosaminide", "X-a-D-Mannoside", 
-"X-PO4", "X-SO4", "Amikacin", "Amikacin", "Amikacin", "Amikacin", 
+"pH 4.5 + L-Norvaline", "pH 4.5 + a-Amino-N-Butyric Acid", "pH 4.5 + p-Aminobenzoic Acid", 
+"pH 4.5 + L-Cysteic Acid", "pH 4.5 + D-Lysine", "pH 4.5 + 5-Hydroxy-L-Lysine", 
+"pH 4.5 + 5-Hydroxy-L-Tryptophan", "pH 4.5 + D,L-Diamino-a,e-Pimelic Acid", 
+"pH 4.5 + Trimethylamine-N-Oxide", "pH 4.5 + Urea", "pH 9.5", 
+"pH 9.5 + L-Alanine", "pH 9.5 + L-Arginine", "pH 9.5 + L-Asparagine", 
+"pH 9.5 + L-Aspartic Acid", "pH 9.5 + L-Glutamic Acid", "pH 9.5 + L-Glutamine", 
+"pH 9.5 + Glycine", "pH 9.5 + L-Histidine", "pH 9.5 + L-Isoleucine", 
+"pH 9.5 + L-Leucine", "pH 9.5 + L-Lysine", "pH 9.5 + L-Methionine", 
+"pH 9.5 + L-Phenylalanine", "pH 9.5 + L-Proline", "pH 9.5 + L-Serine", 
+"pH 9.5 + L-Threonine", "pH 9.5 + L-Tryptophan", "pH 9.5 + L-Tyrosine", 
+"pH 9.5 + L-Valine", "pH 9.5 + Hydroxy-L-Proline", "pH 9.5 + L-Ornithine", 
+"pH 9.5 + L-Homoarginine", "pH 9.5 + L-Homoserine", "pH 9.5 + Anthranilic Acid", 
+"pH 9.5 + L-Norleucine", "pH 9.5 + L-Norvaline", "pH 9.5 + Agmatine", 
+"pH 9.5 + Cadaverine", "pH 9.5 + Putrescine", "pH 9.5 + Histamine", 
+"pH 9.5 + b-Phenylethylamine", "pH 9.5 + Tyramine", "pH 9.5 + Creatine", 
+"pH 9.5 + Trimethylamine-N-Oxide", "pH 9.5 + Urea", "X-Caprylate", 
+"X-a-D-Glucoside", "X-b-D-Glucoside", "X-a-D-Galactoside", "X-b-D-Galactoside", 
+"X-a-D-Glucuronide", "X-b-D-Glucuronide", "X-b-D-Glucosaminide", 
+"X-b-D-Galactosaminide", "X-a-D-Mannoside", "X-PO4", "X-SO4", 
+"Amikacin", "Amikacin", "Amikacin", "Amikacin", "Chlortetracycline", 
 "Chlortetracycline", "Chlortetracycline", "Chlortetracycline", 
-"Chlortetracycline", "Lincomycin", "Lincomycin", "Lincomycin", 
-"Lincomycin", "Amoxicillin", "Amoxicillin", "Amoxicillin", "Amoxicillin", 
-"Cloxacillin", "Cloxacillin", "Cloxacillin", "Cloxacillin", "Lomefloxacin", 
-"Lomefloxacin", "Lomefloxacin", "Lomefloxacin", "Bleomycin", 
-"Bleomycin", "Bleomycin", "Bleomycin", "Colistin", "Colistin", 
-"Colistin", "Colistin", "Minocycline", "Minocycline", "Minocycline", 
-"Minocycline", "Capreomycin", "Capreomycin", "Capreomycin", "Capreomycin", 
-"Demeclocycline", "Demeclocycline", "Demeclocycline", "Demeclocycline", 
-"Nafcillin", "Nafcillin", "Nafcillin", "Nafcillin", "Cefazolin", 
-"Cefazolin", "Cefazolin", "Cefazolin", "Enoxacin", "Enoxacin", 
-"Enoxacin", "Enoxacin", "Nalidixic Acid", "Nalidixic Acid", "Nalidixic Acid", 
+"Lincomycin", "Lincomycin", "Lincomycin", "Lincomycin", "Amoxicillin", 
+"Amoxicillin", "Amoxicillin", "Amoxicillin", "Cloxacillin", "Cloxacillin", 
+"Cloxacillin", "Cloxacillin", "Lomefloxacin", "Lomefloxacin", 
+"Lomefloxacin", "Lomefloxacin", "Bleomycin", "Bleomycin", "Bleomycin", 
+"Bleomycin", "Colistin", "Colistin", "Colistin", "Colistin", 
+"Minocycline", "Minocycline", "Minocycline", "Minocycline", "Capreomycin", 
+"Capreomycin", "Capreomycin", "Capreomycin", "Demeclocycline", 
+"Demeclocycline", "Demeclocycline", "Demeclocycline", "Nafcillin", 
+"Nafcillin", "Nafcillin", "Nafcillin", "Cefazolin", "Cefazolin", 
+"Cefazolin", "Cefazolin", "Enoxacin", "Enoxacin", "Enoxacin", 
+"Enoxacin", "Nalidixic Acid", "Nalidixic Acid", "Nalidixic Acid", 
 "Nalidixic Acid", "Chloramphenicol", "Chloramphenicol", "Chloramphenicol", 
 "Chloramphenicol", "Erythromycin", "Erythromycin", "Erythromycin", 
 "Erythromycin", "Neomycin", "Neomycin", "Neomycin", "Neomycin", 
@@ -317,14 +317,14 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "Potassium Chromate", "Cefuroxime", "Cefuroxime", "Cefuroxime", 
 "Cefuroxime", "5-Fluorouracil", "5-Fluorouracil", "5-Fluorouracil", 
 "5-Fluorouracil", "Rolitetracycline", "Rolitetracycline", "Rolitetracycline", 
-"Rolitetracycline", "Cytosine Arabinoside", "Cytosine Arabinoside", 
-"Cytosine Arabinoside", "Cytosine Arabinoside", "Geneticin (G418)", 
-"Geneticin (G418)", "Geneticin (G418)", "Geneticin (G418)", "Ruthenium Red", 
-"Ruthenium Red", "Ruthenium Red", "Ruthenium Red", "Cesium Chloride", 
-"Cesium Chloride", "Cesium Chloride", "Cesium Chloride", "Glycine", 
-"Glycine", "Glycine", "Glycine", "Thallium (I) Acetate", "Thallium (I) Acetate", 
-"Thallium (I) Acetate", "Thallium (I) Acetate", "Cobalt Chloride", 
-"Cobalt Chloride", "Cobalt Chloride", "Cobalt Chloride", "Manganese (II) Chloride", 
+"Rolitetracycline", "Cytarabine", "Cytarabine", "Cytarabine", 
+"Cytarabine", "Geneticin (G418)", "Geneticin (G418)", "Geneticin (G418)", 
+"Geneticin (G418)", "Ruthenium Red", "Ruthenium Red", "Ruthenium Red", 
+"Ruthenium Red", "Cesium Chloride", "Cesium Chloride", "Cesium Chloride", 
+"Cesium Chloride", "Glycine", "Glycine", "Glycine", "Glycine", 
+"Thallium (I) Acetate", "Thallium (I) Acetate", "Thallium (I) Acetate", 
+"Thallium (I) Acetate", "Cobalt (II) Chloride", "Cobalt (II) Chloride", 
+"Cobalt (II) Chloride", "Cobalt (II) Chloride", "Manganese (II) Chloride", 
 "Manganese (II) Chloride", "Manganese (II) Chloride", "Manganese (II) Chloride", 
 "Trifluoperazine", "Trifluoperazine", "Trifluoperazine", "Trifluoperazine", 
 "Cupric Chloride", "Cupric Chloride", "Cupric Chloride", "Cupric Chloride", 
@@ -340,23 +340,24 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "1-Hydroxy-Pyridine-2-Thione", "1-Hydroxy-Pyridine-2-Thione", 
 "Sodium Cyanate", "Sodium Cyanate", "Sodium Cyanate", "Sodium Cyanate", 
 "Cadmium Chloride", "Cadmium Chloride", "Cadmium Chloride", "Cadmium Chloride", 
-"Iodoacetate", "Iodoacetate", "Iodoacetate", "Iodoacetate", "Sodium Dichromate", 
+"Iodoacetic Acid", "Iodoacetic Acid", "Iodoacetic Acid", "Iodoacetic Acid", 
 "Sodium Dichromate", "Sodium Dichromate", "Sodium Dichromate", 
-"Cefoxitin", "Cefoxitin", "Cefoxitin", "Cefoxitin", "Nitrofurantoin", 
-"Nitrofurantoin", "Nitrofurantoin", "Nitrofurantoin", "Sodium Metaborate", 
+"Sodium Dichromate", "Cefoxitin", "Cefoxitin", "Cefoxitin", "Cefoxitin", 
+"Nitrofurantoin", "Nitrofurantoin", "Nitrofurantoin", "Nitrofurantoin", 
 "Sodium Metaborate", "Sodium Metaborate", "Sodium Metaborate", 
-"Chloramphenicol", "Chloramphenicol", "Chloramphenicol", "Chloramphenicol", 
-"Piperacillin", "Piperacillin", "Piperacillin", "Piperacillin", 
-"Sodium Metavanadate", "Sodium Metavanadate", "Sodium Metavanadate", 
-"Sodium Metavanadate", "Chelerythrine", "Chelerythrine", "Chelerythrine", 
-"Chelerythrine", "Carbenicillin", "Carbenicillin", "Carbenicillin", 
-"Carbenicillin", "Sodium Nitrite", "Sodium Nitrite", "Sodium Nitrite", 
-"Sodium Nitrite", "EGTA", "EGTA", "EGTA", "EGTA", "Promethazine", 
-"Promethazine", "Promethazine", "Promethazine", "Sodium Orthovanadate", 
-"Sodium Orthovanadate", "Sodium Orthovanadate", "Sodium Orthovanadate", 
-"Procaine", "Procaine", "Procaine", "Procaine", "Guanidine Hydrochloride", 
-"Guanidine Hydrochloride", "Guanidine Hydrochloride", "Guanidine Hydrochloride", 
-"Cefmetazole", "Cefmetazole", "Cefmetazole", "Cefmetazole", "D-Cycloserine", 
+"Sodium Metaborate", "Chloramphenicol", "Chloramphenicol", "Chloramphenicol", 
+"Chloramphenicol", "Piperacillin", "Piperacillin", "Piperacillin", 
+"Piperacillin", "Sodium Metavanadate", "Sodium Metavanadate", 
+"Sodium Metavanadate", "Sodium Metavanadate", "Chelerythrine", 
+"Chelerythrine", "Chelerythrine", "Chelerythrine", "Carbenicillin", 
+"Carbenicillin", "Carbenicillin", "Carbenicillin", "Sodium Nitrite", 
+"Sodium Nitrite", "Sodium Nitrite", "Sodium Nitrite", "EGTA", 
+"EGTA", "EGTA", "EGTA", "Promethazine", "Promethazine", "Promethazine", 
+"Promethazine", "Sodium Orthovanadate", "Sodium Orthovanadate", 
+"Sodium Orthovanadate", "Sodium Orthovanadate", "Procaine", "Procaine", 
+"Procaine", "Procaine", "Guanidine Hydrochloride", "Guanidine Hydrochloride", 
+"Guanidine Hydrochloride", "Guanidine Hydrochloride", "Cefmetazole", 
+"Cefmetazole", "Cefmetazole", "Cefmetazole", "D-Cycloserine", 
 "D-Cycloserine", "D-Cycloserine", "D-Cycloserine", "EDTA", "EDTA", 
 "EDTA", "EDTA", "5,7-Dichloro-8-Hydroxy-Quinaldine", "5,7-Dichloro-8-Hydroxy-Quinaldine", 
 "5,7-Dichloro-8-Hydroxy-Quinaldine", "5,7-Dichloro-8-Hydroxy-Quinaldine", 
@@ -398,39 +399,40 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "Rifamycin SV", "Potassium Tellurite", "Potassium Tellurite", 
 "Potassium Tellurite", "Potassium Tellurite", "Sodium Selenite", 
 "Sodium Selenite", "Sodium Selenite", "Sodium Selenite", "Aluminum Sulfate", 
-"Aluminum Sulfate", "Aluminum Sulfate", "Aluminum Sulfate", "Chromium Chloride", 
-"Chromium Chloride", "Chromium Chloride", "Chromium Chloride", 
+"Aluminum Sulfate", "Aluminum Sulfate", "Aluminum Sulfate", "Chromium (III) Chloride", 
+"Chromium (III) Chloride", "Chromium (III) Chloride", "Chromium (III) Chloride", 
 "Ferric Chloride", "Ferric Chloride", "Ferric Chloride", "Ferric Chloride", 
-"L-Glutamic-g-Hydroxamate", "L-Glutamic-g-Hydroxamate", "L-Glutamic-g-Hydroxamate", 
-"L-Glutamic-g-Hydroxamate", "Glycine Hydroxamate", "Glycine Hydroxamate", 
-"Glycine Hydroxamate", "Glycine Hydroxamate", "Chloroxylenol", 
-"Chloroxylenol", "Chloroxylenol", "Chloroxylenol", "Sorbic Acid", 
-"Sorbic Acid", "Sorbic Acid", "Sorbic Acid", "D-Serine", "D-Serine", 
-"D-Serine", "D-Serine", "b-Chloro-L-Alanine", "b-Chloro-L-Alanine", 
-"b-Chloro-L-Alanine", "b-Chloro-L-Alanine", "Thiosalicylate", 
-"Thiosalicylate", "Thiosalicylate", "Thiosalicylate", "Salicylate", 
-"Salicylate", "Salicylate", "Salicylate", "Hygromycin B", "Hygromycin B", 
-"Hygromycin B", "Hygromycin B", "Ethionamide", "Ethionamide", 
-"Ethionamide", "Ethionamide", "4-Aminopyridine", "4-Aminopyridine", 
-"4-Aminopyridine", "4-Aminopyridine", "Sulfachloropyridazine", 
+"L-Glutamic Acid g-Hydroxamate", "L-Glutamic Acid g-Hydroxamate", 
+"L-Glutamic Acid g-Hydroxamate", "L-Glutamic Acid g-Hydroxamate", 
+"Glycine Hydroxamate", "Glycine Hydroxamate", "Glycine Hydroxamate", 
+"Glycine Hydroxamate", "Chloroxylenol", "Chloroxylenol", "Chloroxylenol", 
+"Chloroxylenol", "Sorbic Acid", "Sorbic Acid", "Sorbic Acid", 
+"Sorbic Acid", "D-Serine", "D-Serine", "D-Serine", "D-Serine", 
+"b-Chloro-L-Alanine", "b-Chloro-L-Alanine", "b-Chloro-L-Alanine", 
+"b-Chloro-L-Alanine", "Thiosalicylate", "Thiosalicylate", "Thiosalicylate", 
+"Thiosalicylate", "Salicylate", "Salicylate", "Salicylate", "Salicylate", 
+"Hygromycin B", "Hygromycin B", "Hygromycin B", "Hygromycin B", 
+"Ethionamide", "Ethionamide", "Ethionamide", "Ethionamide", "4-Aminopyridine", 
+"4-Aminopyridine", "4-Aminopyridine", "4-Aminopyridine", "Sulfachloropyridazine", 
 "Sulfachloropyridazine", "Sulfachloropyridazine", "Sulfachloropyridazine", 
 "Sulfamonomethoxine", "Sulfamonomethoxine", "Sulfamonomethoxine", 
 "Sulfamonomethoxine", "Oxycarboxin", "Oxycarboxin", "Oxycarboxin", 
-"Oxycarboxin", "Aminotriazole", "Aminotriazole", "Aminotriazole", 
-"Aminotriazole", "Chlorpromazine", "Chlorpromazine", "Chlorpromazine", 
-"Chlorpromazine", "Niaproof", "Niaproof", "Niaproof", "Niaproof", 
-"Compound 48/80", "Compound 48/80", "Compound 48/80", "Compound 48/80", 
-"Sodium Tungstate", "Sodium Tungstate", "Sodium Tungstate", "Sodium Tungstate", 
-"Lithium Chloride", "Lithium Chloride", "Lithium Chloride", "Lithium Chloride", 
+"Oxycarboxin", "3-Amino-1,2,4-triazole", "3-Amino-1,2,4-triazole", 
+"3-Amino-1,2,4-triazole", "3-Amino-1,2,4-triazole", "Chlorpromazine", 
+"Chlorpromazine", "Chlorpromazine", "Chlorpromazine", "Niaproof", 
+"Niaproof", "Niaproof", "Niaproof", "Compound 48/80", "Compound 48/80", 
+"Compound 48/80", "Compound 48/80", "Sodium Tungstate", "Sodium Tungstate", 
+"Sodium Tungstate", "Sodium Tungstate", "Lithium Chloride", "Lithium Chloride", 
+"Lithium Chloride", "Lithium Chloride", "D,L-Methionine Hydroxamate", 
 "D,L-Methionine Hydroxamate", "D,L-Methionine Hydroxamate", "D,L-Methionine Hydroxamate", 
-"D,L-Methionine Hydroxamate", "Tannic Acid", "Tannic Acid", "Tannic Acid", 
-"Tannic Acid", "Chlorambucil", "Chlorambucil", "Chlorambucil", 
-"Chlorambucil", "Cefamandole", "Cefamandole", "Cefamandole", 
-"Cefamandole", "Cefoperazone", "Cefoperazone", "Cefoperazone", 
-"Cefoperazone", "Cefsulodin", "Cefsulodin", "Cefsulodin", "Cefsulodin", 
-"Caffeine", "Caffeine", "Caffeine", "Caffeine", "Phenylarsine Oxide", 
-"Phenylarsine Oxide", "Phenylarsine Oxide", "Phenylarsine Oxide", 
-"Ketoprofen", "Ketoprofen", "Ketoprofen", "Ketoprofen", "Sodium Pyrophosphate Decahydrate", 
+"Tannic Acid", "Tannic Acid", "Tannic Acid", "Tannic Acid", "Chlorambucil", 
+"Chlorambucil", "Chlorambucil", "Chlorambucil", "Cefamandole Nafate", 
+"Cefamandole Nafate", "Cefamandole Nafate", "Cefamandole Nafate", 
+"Cefoperazone", "Cefoperazone", "Cefoperazone", "Cefoperazone", 
+"Cefsulodin", "Cefsulodin", "Cefsulodin", "Cefsulodin", "Caffeine", 
+"Caffeine", "Caffeine", "Caffeine", "Phenylarsine Oxide", "Phenylarsine Oxide", 
+"Phenylarsine Oxide", "Phenylarsine Oxide", "Ketoprofen", "Ketoprofen", 
+"Ketoprofen", "Ketoprofen", "Sodium Pyrophosphate Decahydrate", 
 "Sodium Pyrophosphate Decahydrate", "Sodium Pyrophosphate Decahydrate", 
 "Sodium Pyrophosphate Decahydrate", "Thiamphenicol", "Thiamphenicol", 
 "Thiamphenicol", "Thiamphenicol", "Trifluorothymidine", "Trifluorothymidine", 
@@ -438,8 +440,8 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "Pipemidic Acid", "Pipemidic Acid", "Pipemidic Acid", "Azathioprine", 
 "Azathioprine", "Azathioprine", "Azathioprine", "Poly-L-lysine", 
 "Poly-L-lysine", "Poly-L-lysine", "Poly-L-lysine", "Sulfisoxazole", 
-"Sulfisoxazole", "Sulfisoxazole", "Sulfisoxazole", "Pentachlorophenol (PCP)", 
-"Pentachlorophenol (PCP)", "Pentachlorophenol (PCP)", "Pentachlorophenol (PCP)", 
+"Sulfisoxazole", "Sulfisoxazole", "Sulfisoxazole", "Pentachlorophenol", 
+"Pentachlorophenol", "Pentachlorophenol", "Pentachlorophenol", 
 "Sodium m-Arsenite", "Sodium m-Arsenite", "Sodium m-Arsenite", 
 "Sodium m-Arsenite", "Sodium Bromate", "Sodium Bromate", "Sodium Bromate", 
 "Sodium Bromate", "Lidocaine", "Lidocaine", "Lidocaine", "Lidocaine", 
@@ -451,28 +453,27 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "Semicarbazide Hydrochloride", "Semicarbazide Hydrochloride", 
 "Tinidazole", "Tinidazole", "Tinidazole", "Tinidazole", "Aztreonam", 
 "Aztreonam", "Aztreonam", "Aztreonam", "Triclosan", "Triclosan", 
-"Triclosan", "Triclosan", "3,5-Diamino-1,2,4-Triazole (Guanazole)", 
-"3,5-Diamino-1,2,4-Triazole (Guanazole)", "3,5-Diamino-1,2,4-Triazole (Guanazole)", 
-"3,5-Diamino-1,2,4-Triazole (Guanazole)", "Myricetin", "Myricetin", 
-"Myricetin", "Myricetin", "5-Fluoro-5'-Deoxyuridine", "5-Fluoro-5'-Deoxyuridine", 
-"5-Fluoro-5'-Deoxyuridine", "5-Fluoro-5'-Deoxyuridine", "2-Phenylphenol", 
-"2-Phenylphenol", "2-Phenylphenol", "2-Phenylphenol", "Plumbagin", 
-"Plumbagin", "Plumbagin", "Plumbagin", "Josamycin", "Josamycin", 
-"Josamycin", "Josamycin", "Gallic Acid", "Gallic Acid", "Gallic Acid", 
-"Gallic Acid", "Coumarin", "Coumarin", "Coumarin", "Coumarin", 
+"Triclosan", "Triclosan", "Guanazole", "Guanazole", "Guanazole", 
+"Guanazole", "Myricetin", "Myricetin", "Myricetin", "Myricetin", 
+"5-Fluoro-5'-Deoxyuridine", "5-Fluoro-5'-Deoxyuridine", "5-Fluoro-5'-Deoxyuridine", 
+"5-Fluoro-5'-Deoxyuridine", "2-Phenylphenol", "2-Phenylphenol", 
+"2-Phenylphenol", "2-Phenylphenol", "Plumbagin", "Plumbagin", 
+"Plumbagin", "Plumbagin", "Josamycin", "Josamycin", "Josamycin", 
+"Josamycin", "Gallic Acid", "Gallic Acid", "Gallic Acid", "Gallic Acid", 
+"Coumarin", "Coumarin", "Coumarin", "Coumarin", "Methyltrioctylammonium Chloride", 
 "Methyltrioctylammonium Chloride", "Methyltrioctylammonium Chloride", 
-"Methyltrioctylammonium Chloride", "Methyltrioctylammonium Chloride", 
-"Harmane", "Harmane", "Harmane", "Harmane", "2,4-Dinitrophenol", 
-"2,4-Dinitrophenol", "2,4-Dinitrophenol", "2,4-Dinitrophenol", 
-"Chlorhexidine", "Chlorhexidine", "Chlorhexidine", "Chlorhexidine", 
-"Umbelliferone", "Umbelliferone", "Umbelliferone", "Umbelliferone", 
-"Cinnamic Acid", "Cinnamic Acid", "Cinnamic Acid", "Cinnamic Acid", 
-"Disulphiram", "Disulphiram", "Disulphiram", "Disulphiram", "Iodonitro Tetrazolium Violet", 
+"Methyltrioctylammonium Chloride", "Harmane", "Harmane", "Harmane", 
+"Harmane", "2,4-Dinitrophenol", "2,4-Dinitrophenol", "2,4-Dinitrophenol", 
+"2,4-Dinitrophenol", "Chlorhexidine", "Chlorhexidine", "Chlorhexidine", 
+"Chlorhexidine", "Umbelliferone", "Umbelliferone", "Umbelliferone", 
+"Umbelliferone", "Cinnamic Acid (trans)", "Cinnamic Acid (trans)", 
+"Cinnamic Acid (trans)", "Cinnamic Acid (trans)", "Disulphiram", 
+"Disulphiram", "Disulphiram", "Disulphiram", "Iodonitro Tetrazolium Violet", 
 "Iodonitro Tetrazolium Violet", "Iodonitro Tetrazolium Violet", 
-"Iodonitro Tetrazolium Violet", "Phenyl-Methyl-Sulfonyl Fluoride (PMSF)", 
-"Phenyl-Methyl-Sulfonyl Fluoride (PMSF)", "Phenyl-Methyl-Sulfonyl Fluoride (PMSF)", 
-"Phenyl-Methyl-Sulfonyl Fluoride (PMSF)", "FCCP", "FCCP", "FCCP", 
-"FCCP", "D,L-Thioctic Acid", "D,L-Thioctic Acid", "D,L-Thioctic Acid", 
+"Iodonitro Tetrazolium Violet", "Phenyl-Methyl-Sulfonyl Fluoride", 
+"Phenyl-Methyl-Sulfonyl Fluoride", "Phenyl-Methyl-Sulfonyl Fluoride", 
+"Phenyl-Methyl-Sulfonyl Fluoride", "FCCP", "FCCP", "FCCP", "FCCP", 
+"D,L-Thioctic Acid", "D,L-Thioctic Acid", "D,L-Thioctic Acid", 
 "D,L-Thioctic Acid", "Lawsone", "Lawsone", "Lawsone", "Lawsone", 
 "Phenethicillin", "Phenethicillin", "Phenethicillin", "Phenethicillin", 
 "Blasticidin S", "Blasticidin S", "Blasticidin S", "Blasticidin S", 
@@ -482,8 +483,8 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "Dihydrostreptomycin", "Dihydrostreptomycin", "Hydroxylamine", 
 "Hydroxylamine", "Hydroxylamine", "Hydroxylamine", "Hexaminecobalt (III) Chloride", 
 "Hexaminecobalt (III) Chloride", "Hexaminecobalt (III) Chloride", 
-"Hexaminecobalt (III) Chloride", "Thioglycerol", "Thioglycerol", 
-"Thioglycerol", "Thioglycerol", "Polymyxin B", "Polymyxin B", 
+"Hexaminecobalt (III) Chloride", "a-Thioglycerol", "a-Thioglycerol", 
+"a-Thioglycerol", "a-Thioglycerol", "Polymyxin B", "Polymyxin B", 
 "Polymyxin B", "Polymyxin B", "Amitriptyline", "Amitriptyline", 
 "Amitriptyline", "Amitriptyline", "Apramycin", "Apramycin", "Apramycin", 
 "Apramycin", "Benserazide", "Benserazide", "Benserazide", "Benserazide", 
@@ -502,16 +503,16 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "4-Hydroxycoumarin", "4-Hydroxycoumarin", "Oxytetracycline", 
 "Oxytetracycline", "Oxytetracycline", "Oxytetracycline", "Pridinol", 
 "Pridinol", "Pridinol", "Pridinol", "Captan", "Captan", "Captan", 
-"Captan", "3,5-Dinitrobenzene", "3,5-Dinitrobenzene", "3,5-Dinitrobenzene", 
-"3,5-Dinitrobenzene", "8-Hydroxyquinoline", "8-Hydroxyquinoline", 
-"8-Hydroxyquinoline", "8-Hydroxyquinoline", "Patulin", "Patulin", 
-"Patulin", "Patulin", "Tolylfluanid", "Tolylfluanid", "Tolylfluanid", 
-"Tolylfluanid", "Troleandomycin", "Troleandomycin", "Troleandomycin", 
-"Troleandomycin", "Negative Control", "Negative Control", "Negative Control", 
-"a-Cyclodextrin", "Dextrin", "Glycogen", "Maltitol", "Maltotriose", 
-"D-Maltose", "D-Trehalose", "D-Cellobiose", "b-Gentiobiose", 
-"D-Glucose-6-Phosphate", "a-D-Glucose-1-Phosphate", "L-Glucose", 
-"a-D-Glucose", "a-D-Glucose", "a-D-Glucose", "3-O-Methyl-D-Glucose", 
+"Captan", "3,5-Dinitrobenzoic Acid", "3,5-Dinitrobenzoic Acid", 
+"3,5-Dinitrobenzoic Acid", "3,5-Dinitrobenzoic Acid", "8-Hydroxyquinoline", 
+"8-Hydroxyquinoline", "8-Hydroxyquinoline", "8-Hydroxyquinoline", 
+"Patulin", "Patulin", "Patulin", "Patulin", "Tolylfluanid", "Tolylfluanid", 
+"Tolylfluanid", "Tolylfluanid", "Troleandomycin", "Troleandomycin", 
+"Troleandomycin", "Troleandomycin", "Negative Control", "Negative Control", 
+"Negative Control", "a-Cyclodextrin", "Dextrin", "Glycogen", 
+"Maltitol", "Maltotriose", "D-Maltose", "D-Trehalose", "D-Cellobiose", 
+"b-Gentiobiose", "D-Glucose-6-Phosphate", "a-D-Glucose-1-Phosphate", 
+"L-Glucose", "a-D-Glucose", "a-D-Glucose", "a-D-Glucose", "3-O-Methyl-D-Glucose", 
 "a-Methyl-D-Glucoside", "b-Methyl-D-Glucoside", "D-Salicin", 
 "D-Sorbitol", "N-Acetyl-D-Glucosamine", "D-Glucosaminic Acid", 
 "D-Glucuronic Acid", "Chondroitin 6-Sulfate", "Mannan", "D-Mannose", 
@@ -569,7 +570,7 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "a-D-Glucose", "Negative Control", "Negative Control", "Negative Control", 
 "Phe-Gly", "Phe-Ile", "Phe-Met", "Phe-Phe", "Phe-Pro", "Phe-Ser", 
 "Phe-Trp", "Phe-Tyr", "Phe-Val", "Pro-Ala", "Pro-Arg", "Pro-Asn", 
-"Pro-Asp", "Pro-Glu", "Pro-Gln", "Pro-Gly", "Pro-Hyp", "Pro-lle", 
+"Pro-Asp", "Pro-Glu", "Pro-Gln", "Pro-Gly", "Pro-Hyp", "Pro-Ile", 
 "Pro-Leu", "Pro-Lys", "Pro-Phe", "Pro-Pro", "Pro-Ser", "Pro-Trp", 
 "Pro-Tyr", "Pro-Val", "Ser-Ala", "Ser-Asn", "Ser-Asp", "Ser-Glu", 
 "Ser-Gln", "Ser-Gly", "Ser-His", "Ser-Leu", "Ser-Met", "Ser-Phe", 
@@ -593,9 +594,9 @@ structure(c("Negative Control", "Dextrin", "D-Maltose", "D-Trehalose",
 "Manganese Chloride", "Manganese Chloride", "Manganese Chloride", 
 "Zinc Chloride", "Zinc Chloride", "Zinc Chloride", "Zinc Chloride", 
 "Copper (II) Chloride", "Copper (II) Chloride", "Copper (II) Chloride", 
-"Copper (II) Chloride", "Cobalt Chloride", "Cobalt Chloride", 
-"Cobalt Chloride", "Cobalt Chloride", "Iodine", "Iodine", "Iodine", 
-"Iodine", "Sodium Phosphate", "Sodium Phosphate", "Sodium Phosphate", 
+"Copper (II) Chloride", "Cobalt (II) Chloride", "Cobalt (II) Chloride", 
+"Cobalt (II) Chloride", "Cobalt (II) Chloride", "Iodine", "Iodine", 
+"Iodine", "Iodine", "Sodium Phosphate", "Sodium Phosphate", "Sodium Phosphate", 
 "Sodium Phosphate", "Sodium Sulfate", "Sodium Sulfate", "Sodium Sulfate", 
 "Sodium Sulfate", "Sodium Molybdate Dihydrate", "Sodium Molybdate Dihydrate", 
 "Sodium Molybdate Dihydrate", "Sodium Molybdate Dihydrate", "Sodium Tungstate Dihydrate", 
